==> v1.0.1.tar.gz: zyos_go_order_relate_rule/rule/relate_commission.go <==
package rule

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/lib/comm_plan"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/svc"
	"context"
	"errors"
	"golang.org/x/sync/errgroup"
	"sync"
	"xorm.io/xorm"
)

// BatchGetCommission 批量分佣
func BatchGetCommission(eg *xorm.Engine, dbName string, commissionParamList []*md.CommissionFirstParam) (map[string]*comm_plan.LvUser, error) {
	var (
		isShare          = false
		isAllLevelReturn = false
	)
	goodsId2lvUser := make(map[string]*comm_plan.LvUser, len(commissionParamList))
	if len(commissionParamList) == 0 {
		return goodsId2lvUser, errors.New("参数错误")
	}

	group, _ := errgroup.WithContext(context.Background())
	var mu sync.Mutex

	for _, param := range commissionParamList {
		param := param // 为下面的闭包创建局部变量
		group.Go(func() error {
			if param.IsShare != 0 {
				isShare = true
			}

			if param.IsAllLevelReturn != 0 {
				isAllLevelReturn = true
			}

			if param.GoodsId == "" {
				return errors.New("商品ID缺失")
			}

			_, _, _, _, lvUser, err := svc.GetRewardCommission(eg, &param.CommissionParam, isShare, param.Uid, param.Provider, dbName, isAllLevelReturn, map[string]string{})
			if err != nil {
				return err
			}
			mu.Lock()
			goodsId2lvUser[param.GoodsId] = lvUser
			mu.Unlock()

			return nil
		})
	}
	if err := group.Wait(); err != nil {
		return goodsId2lvUser, errors.New("处理错误")
	}

	return goodsId2lvUser, nil
}

==> v1.0.2.tar.gz: zyos_go_order_relate_rule/rule/relate_commission.go <==
package rule

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/lib/comm_plan"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/svc"
	"context"
	"errors"
	"golang.org/x/sync/errgroup"
	"sync"
	"xorm.io/xorm"
)

// BatchGetCommission 批量分佣
func BatchGetCommission(eg *xorm.Engine, dbName string, commissionParamList []*md.CommissionFirstParam) (map[string]*comm_plan.LvUser, error) {
	var (
		isShare          = false
		isAllLevelReturn = false
	)
	goodsId2lvUser := make(map[string]*comm_plan.LvUser, len(commissionParamList))
	if len(commissionParamList) == 0 {
		return goodsId2lvUser, errors.New("参数错误")
	}

	group, _ := errgroup.WithContext(context.Background())
	var mu sync.Mutex
	virCfg := db.SysCfgFindWithDb(eg, dbName, "virtual_coin_rebate_type")
	var virType = "price"
	if virCfg["virtual_coin_rebate_type"] != "" {
		virType = virCfg["virtual_coin_rebate_type"]
	}
	for _, param := range commissionParamList {
		param := param // 为下面的闭包创建局部变量
		group.Go(func() error {
			if param.IsShare != 0 {
				isShare = true
			}

			if param.IsAllLevelReturn != 0 {
				isAllLevelReturn = true
			}

			if param.GoodsId == "" {
				return errors.New("商品ID缺失")
			}

			_, _, _, _, lvUser, err := svc.GetRewardCommission(eg, &param.CommissionParam, isShare, param.Uid, param.Provider, dbName, isAllLevelReturn, map[string]string{}, virType)
			if err != nil {
				return err
			}
			mu.Lock()
			goodsId2lvUser[param.GoodsId] = lvUser
			mu.Unlock()

			return nil
		})
	}
	if err := group.Wait(); err != nil {
		return goodsId2lvUser, errors.New("处理错误")
	}

	return goodsId2lvUser, nil
}
